@@ -7,7 +7,7 @@
 #' @examples
 #' library(dplyr)
 #' N <- 100
-#' df <- data_frame(
+#' df <- tibble(
 #'   id = 1:N,
 #'   v1 = sample(5, N, TRUE),
 #'   v2 = sample(1e6, N, TRUE)
@@ -19,7 +19,6 @@
 #' @return a data.frame 
 #' @export
 
-
 sum_up <- function(df, ...,  d = FALSE, wt = NULL) {
   wt = dplyr::enquo(wt)
   if (rlang::is_null(rlang::f_rhs(wt))) {
@@ -36,16 +35,16 @@ sum_up <- function(df, ...,  d = FALSE, wt = NULL) {
   nums <- sapply(df, is.numeric)
   nums_name <- names(nums[nums == TRUE])
   vars <- intersect(vars, nums_name)
-  if (!length(vars)) stop("Please select at least one non-numeric variable", call. = FALSE)
-  df <- dplyr::select_at(df, c(vars, byvars, wtvar))
+  if (!length(vars)) stop("Please select at least one numeric variable", call. = FALSE)
+  df <- dplyr::select(df, dplyr::all_of(c(vars, byvars, wtvar)))
   # bug for do in data.table
-  df <- dplyr::do(df, describe(!!rlang::sym("."), d = d, wtvar = wtvar, byvars = byvars))
-  out <- dplyr::arrange_at(df, c(byvars, "Variable"))
+  df <- dplyr::summarize(df, describe(dplyr::across(), d = d, wtvar = wtvar, byvars = byvars))
+  out <- dplyr::arrange(df, dplyr::across(dplyr::all_of(c(byvars, "Variable"))))
   # reorder
   if (d) {
-    out1 <- dplyr::select_at(out, c(byvars, "Variable", "Obs", "Missing", "Mean", "StdDev", "Skewness", "Kurtosis"))
-    out2 <- dplyr::select_at(out, c(byvars, "Variable", "Min", "p1", "p5", "p10", "p25", "p50"))
-    out3 <- dplyr::select_at(out, c(byvars, "Variable", "p50", "p75", "p90", "p95", "p99", "Max"))
+    out1 <- dplyr::select(out, dplyr::all_of(c(byvars, "Variable", "Obs", "Missing", "Mean", "StdDev", "Skewness", "Kurtosis")))
+    out2 <- dplyr::select(out, dplyr::all_of(c(byvars, "Variable", "Min", "p1", "p5", "p10", "p25", "p50")))
+    out3 <- dplyr::select(out, dplyr::all_of(c(byvars, "Variable", "p50", "p75", "p90", "p95", "p99", "Max")))
     statascii(out1, n_groups = length(byvars) + 1)
     cat("\n")
     statascii(out2, n_groups = length(byvars) + 1)
@@ -54,7 +53,7 @@ sum_up <- function(df, ...,  d = FALSE, wt = NULL) {
   } 
   else{
     #reorder
-    out <- dplyr::select_at(out, c(byvars, "Variable", setdiff(names(out), c(byvars, "Variable"))))
+    out <- dplyr::select(out, dplyr::all_of(c(byvars, "Variable", setdiff(names(out), c(byvars, "Variable")))))
     statascii(out, n_groups = length(byvars) + 1)
   }
   invisible(out)
@@ -64,11 +63,11 @@ sum_up <- function(df, ...,  d = FALSE, wt = NULL) {
 
 describe <- function(df, d = FALSE, wtvar = character(0),  byvars = character(0)){
   if (length(byvars)){
-    df <- dplyr::select_at(df, setdiff(names(df), byvars))
+    df <- dplyr::select(df, dplyr::all_of(setdiff(names(df), byvars)))
   }
   if (length(wtvar)){
     w <- df[[wtvar]]
-    df <- dplyr::select_at(df, setdiff(names(df), wtvar))
+    df <- dplyr::select(df, dplyr::all_of(setdiff(names(df), wtvar)))
   }
   else{
     w <- NULL
@@ -86,14 +85,14 @@ describe <- function(df, d = FALSE, wtvar = character(0),  byvars = character(0)
       })
     }else{
       sum <- lapply(df ,function(x){
-        x_omit <- na.omit(x)
-      c(length(x_omit), length(x) - length(x_omit), mean(x_omit), sd(x_omit), matrixStats::colRanges(x_omit, dim = c(length(x_omit), 1)))
+        x_omit <- stats::na.omit(x)
+      c(length(x_omit), length(x) - length(x_omit), mean(x_omit), stats::sd(x_omit), matrixStats::colRanges(x_omit, dim = c(length(x_omit), 1)))
       })
     }
     sum <- do.call(cbind, sum)
     sum <- as.data.frame(t(sum))
     sum <- dplyr::bind_cols(dplyr::tibble(names), sum)
-    sum <- setNames(sum, c("Variable", "Obs","Missing","Mean","StdDev","Min", "Max"))
+    sum <- stats::setNames(sum, c("Variable", "Obs","Missing","Mean","StdDev","Min", "Max"))
   } else {
     N <- nrow(df)
     f=function(x){
@@ -108,7 +107,7 @@ describe <- function(df, d = FALSE, wtvar = character(0),  byvars = character(0)
         sum_higher[3] <- sum_higher[3]/sum_higher[1]^4
         sum_quantile <- pctile(x_omit, c(0, 0.01, 0.05, 0.1, 0.25, 0.50, 0.75, 0.9, 0.95, 0.99, 1), wt = w_omit)
       } else{
-        x_omit <- na.omit(x)
+        x_omit <- stats::na.omit(x)
         m <- mean(x_omit)
         sum_higher <- colMeans(cbind((x_omit-m)^2,(x_omit-m)^3,(x_omit-m)^4))
         sum_higher[1] <- sqrt(sum_higher[1])
@@ -119,11 +118,11 @@ describe <- function(df, d = FALSE, wtvar = character(0),  byvars = character(0)
       n_NA <- length(x) - length(x_omit)
       sum <- c(N-n_NA, n_NA, m, sum_higher, sum_quantile)
     }
-    sum <- mclapply(df, f)
+    sum <- parallel::mclapply(df, f)
     sum <- do.call(cbind, sum)
     sum <- as.data.frame(t(sum))
     sum <- dplyr::bind_cols(dplyr::tibble(names), sum)
-    sum <- setNames(sum,  c("Variable", "Obs","Missing","Mean","StdDev","Skewness","Kurtosis","Min","p1","p5","p10","p25","p50","p75","p90","p95","p99","Max"))
+    sum <- stats::setNames(sum,  c("Variable", "Obs","Missing","Mean","StdDev","Skewness","Kurtosis","Min","p1","p5","p10","p25","p50","p75","p90","p95","p99","Max"))
   }
   sum
 }
